===============
Getting started
===============

Here you will find two resources for getting started with skan: instructions
for how to install it, and a short tutorial explaining the basics.

.. toctree::
   :maxdepth: 1

   install
   getting_started
